pub trait DataProvider {
// Required method
fn provide(
&self,
table: &str,
selected_columns: &[String],
) -> Result<Vec<Row>, String>;
}Expand description
DataProvider is a component that used to provide and map the data to the GitQL Engine
User should implement DataProvider trait for each data format for example files, logs, api
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".